@@ -52,11 +52,11 @@ class Freebox(IPlugin):
 				if rs['idx_sec'] <> "":
 				# séparation de rs['idx'], nombre  
 					# search position '|' dans rs['idx']	
-				bodies = rs['boy']
-				log.msg("BODIES  :  %s" % (bodies))
-				log.msg("number  :  %s" % (int(rs['idx'])))
+					bodies = rs['boy']
+					log.msg("BODIES  :  %s" % (bodies))
+					log.msg("number  :  %s" % (int(rs['idx'])))
 		# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-				For rx to range [1, int(rs['idx_sec'])]: 				
+				for rx in range (1, int(rs['idx_sec'])): 				
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx'])
 #					log.msg("resp  :  %s" % (req))				
 #					resp = requests.get (req)
